pub struct MatchmakingSettings {
pub opponent_positions: Vec<OpponentPositionSettings>,
pub percentile_threshold: f64,
}Fields
opponent_positions: Vec<OpponentPositionSettings>percentile_threshold: f64Trait Implementations
Sourceimpl Clone for MatchmakingSettings
impl Clone for MatchmakingSettings
Sourcefn clone(&self) -> MatchmakingSettings
fn clone(&self) -> MatchmakingSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MatchmakingSettings
impl Debug for MatchmakingSettings
Sourceimpl<'de> Deserialize<'de> for MatchmakingSettings
impl<'de> Deserialize<'de> for MatchmakingSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MatchmakingSettings
impl JsonSchema for MatchmakingSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for MatchmakingSettings
impl Serialize for MatchmakingSettings
Sourceimpl Tsify for MatchmakingSettings
impl Tsify for MatchmakingSettings
const DECL: &'static str = "export interface MatchmakingSettings {\n opponent_positions: OpponentPositionSettings[];\n percentile_threshold: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>